@@ -9,14 +9,13 @@ use base (
     'WebService::Shippo::Resource',
     'WebService::Shippo::Creator',
     'WebService::Shippo::Fetcher',
-    'WebService::Shippo::Lister',
     'WebService::Shippo::Updater',
 
 );
 
-sub api_resource { 'carrier_accounts' }    # why not "carrier/accounts", which
-                                           # would be consistent with Customs
-                                           # Declaration resource?
+sub api_resource ()     { 'carrier_accounts' }
+sub collection_class () { 'WebService::Shippo::CarrierAccounts' }
+sub item_class ()       { __PACKAGE__ }
 
 sub activate
 {
@@ -71,8 +70,10 @@ sub enable_production_mode
 }
 
 package    # Hide from PAUSE
-    WebService::Shippo::CarrierAccountList;
-use base ( 'WebService::Shippo::ObjectList' );
+    WebService::Shippo::CarrierAccounts;
+use base ( 'WebService::Shippo::Collection' );
+sub item_class ()       { 'WebService::Shippo::CarrierAccount' }
+sub collection_class () { __PACKAGE__ }
 
 BEGIN {
     no warnings 'once';
