@@ -7,15 +7,17 @@ use base (
     'WebService::Shippo::Resource',
     'WebService::Shippo::Creator',
     'WebService::Shippo::Fetcher',
-    'WebService::Shippo::Lister',
-
 );
 
-sub api_resource { 'customs/items' }
+sub api_resource ()     { 'customs/items' }
+sub collection_class () { 'WebService::Shippo::CustomsItems' }
+sub item_class ()       { __PACKAGE__ }
 
-package                               # Hide from PAUSE
-    WebService::Shippo::CustomsItemList;
-use base ( 'WebService::Shippo::ObjectList' );
+package    # Hide from PAUSE
+    WebService::Shippo::CustomsItems;
+use base ( 'WebService::Shippo::Collection' );
+sub item_class ()       { 'WebService::Shippo::CustomsItem' }
+sub collection_class () { __PACKAGE__ }
 
 BEGIN {
     no warnings 'once';
